"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def check_domain_availability(DomainName=None, IdnLangCode=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            
    :type DomainName: string
    :param IdnLangCode: Reserved for future use.
    :type IdnLangCode: string
    """
    pass

def delete_tags_for_domain(DomainName=None, TagsToDelete=None):
    """
    :param DomainName: [REQUIRED]
            The domain for which you want to delete one or more tags.
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Hyphens are allowed only when theyre surrounded by letters, numbers, or other hyphens. You cant specify a hyphen at the beginning or end of a label. To specify an Internationalized Domain Name, you must convert the name to Punycode.
            Required: Yes
            
    :type DomainName: string
    :param TagsToDelete: [REQUIRED]
            A list of tag keys to delete.
            Type: A list that contains the keys of the tags that you want to delete.
            Default: None
            Required: No
            '>
            (string) --
            
    :type TagsToDelete: list
    """
    pass

def disable_domain_auto_renew(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --
            
    :type DomainName: string
    """
    pass

def disable_domain_transfer_lock(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            Return typedict
            ReturnsResponse Syntax{
              'OperationId': 'string'
            }
            Response Structure
            (dict) --The DisableDomainTransferLock response includes the following element.
            OperationId (string) --Identifier for tracking the progress of the request. To use this ID to query the operation status, use GetOperationDetail.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            
            
    :type DomainName: string
    """
    pass

def enable_domain_auto_renew(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --
            
    :type DomainName: string
    """
    pass

def enable_domain_transfer_lock(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            Return typedict
            ReturnsResponse Syntax{
              'OperationId': 'string'
            }
            Response Structure
            (dict) --The EnableDomainTransferLock response includes the following elements.
            OperationId (string) --Identifier for tracking the progress of the request. To use this ID to query the operation status, use GetOperationDetail.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            
            
    :type DomainName: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_contact_reachability_status(domainName=None):
    """
    :param domainName: The name of the domain for which you want to know whether the registrant contact has confirmed that the email address is valid.
            Type: String
            Default: None
            Required: Yes
            Return typedict
            ReturnsResponse Syntax{
              'domainName': 'string',
              'status': 'PENDING'|'DONE'|'EXPIRED'
            }
            Response Structure
            (dict) --
            domainName (string) --The domain name for which you requested the reachability status.
            status (string) --Whether the registrant contact has responded. PENDING indicates that we sent the confirmation email and haven't received a response yet, DONE indicates that we sent the email and got confirmation from the registrant contact, and EXPIRED indicates that the time limit expired before the registrant contact responded.
            Type: String
            Valid values: PENDING , DONE , EXPIRED
            
            
    :type domainName: string
    """
    pass

def get_domain_detail(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            Return typedict
            ReturnsResponse Syntax{
              'DomainName': 'string',
              'Nameservers': [
                {
                  'Name': 'string',
                  'GlueIps': [
                    'string',
                  ]
                },
              ],
              'AutoRenew': True|False,
              'AdminContact': {
                'FirstName': 'string',
                'LastName': 'string',
                'ContactType': 'PERSON'|'COMPANY'|'ASSOCIATION'|'PUBLIC_BODY'|'RESELLER',
                'OrganizationName': 'string',
                'AddressLine1': 'string',
                'AddressLine2': 'string',
                'City': 'string',
                'State': 'string',
                'CountryCode': 'AD'|'AE'|'AF'|'AG'|'AI'|'AL'|'AM'|'AN'|'AO'|'AQ'|'AR'|'AS'|'AT'|'AU'|'AW'|'AZ'|'BA'|'BB'|'BD'|'BE'|'BF'|'BG'|'BH'|'BI'|'BJ'|'BL'|'BM'|'BN'|'BO'|'BR'|'BS'|'BT'|'BW'|'BY'|'BZ'|'CA'|'CC'|'CD'|'CF'|'CG'|'CH'|'CI'|'CK'|'CL'|'CM'|'CN'|'CO'|'CR'|'CU'|'CV'|'CX'|'CY'|'CZ'|'DE'|'DJ'|'DK'|'DM'|'DO'|'DZ'|'EC'|'EE'|'EG'|'ER'|'ES'|'ET'|'FI'|'FJ'|'FK'|'FM'|'FO'|'FR'|'GA'|'GB'|'GD'|'GE'|'GH'|'GI'|'GL'|'GM'|'GN'|'GQ'|'GR'|'GT'|'GU'|'GW'|'GY'|'HK'|'HN'|'HR'|'HT'|'HU'|'ID'|'IE'|'IL'|'IM'|'IN'|'IQ'|'IR'|'IS'|'IT'|'JM'|'JO'|'JP'|'KE'|'KG'|'KH'|'KI'|'KM'|'KN'|'KP'|'KR'|'KW'|'KY'|'KZ'|'LA'|'LB'|'LC'|'LI'|'LK'|'LR'|'LS'|'LT'|'LU'|'LV'|'LY'|'MA'|'MC'|'MD'|'ME'|'MF'|'MG'|'MH'|'MK'|'ML'|'MM'|'MN'|'MO'|'MP'|'MR'|'MS'|'MT'|'MU'|'MV'|'MW'|'MX'|'MY'|'MZ'|'NA'|'NC'|'NE'|'NG'|'NI'|'NL'|'NO'|'NP'|'NR'|'NU'|'NZ'|'OM'|'PA'|'PE'|'PF'|'PG'|'PH'|'PK'|'PL'|'PM'|'PN'|'PR'|'PT'|'PW'|'PY'|'QA'|'RO'|'RS'|'RU'|'RW'|'SA'|'SB'|'SC'|'SD'|'SE'|'SG'|'SH'|'SI'|'SK'|'SL'|'SM'|'SN'|'SO'|'SR'|'ST'|'SV'|'SY'|'SZ'|'TC'|'TD'|'TG'|'TH'|'TJ'|'TK'|'TL'|'TM'|'TN'|'TO'|'TR'|'TT'|'TV'|'TW'|'TZ'|'UA'|'UG'|'US'|'UY'|'UZ'|'VA'|'VC'|'VE'|'VG'|'VI'|'VN'|'VU'|'WF'|'WS'|'YE'|'YT'|'ZA'|'ZM'|'ZW',
                'ZipCode': 'string',
                'PhoneNumber': 'string',
                'Email': 'string',
                'Fax': 'string',
                'ExtraParams': [
                  {
                    'Name': 'DUNS_NUMBER'|'BRAND_NUMBER'|'BIRTH_DEPARTMENT'|'BIRTH_DATE_IN_YYYY_MM_DD'|'BIRTH_COUNTRY'|'BIRTH_CITY'|'DOCUMENT_NUMBER'|'AU_ID_NUMBER'|'AU_ID_TYPE'|'CA_LEGAL_TYPE'|'CA_BUSINESS_ENTITY_TYPE'|'ES_IDENTIFICATION'|'ES_IDENTIFICATION_TYPE'|'ES_LEGAL_FORM'|'FI_BUSINESS_NUMBER'|'FI_ID_NUMBER'|'IT_PIN'|'RU_PASSPORT_DATA'|'SE_ID_NUMBER'|'SG_ID_NUMBER'|'VAT_NUMBER',
                    'Value': 'string'
                  },
                ]
              },
              'RegistrantContact': {
                'FirstName': 'string',
                'LastName': 'string',
                'ContactType': 'PERSON'|'COMPANY'|'ASSOCIATION'|'PUBLIC_BODY'|'RESELLER',
                'OrganizationName': 'string',
                'AddressLine1': 'string',
                'AddressLine2': 'string',
                'City': 'string',
                'State': 'string',
                'CountryCode': 'AD'|'AE'|'AF'|'AG'|'AI'|'AL'|'AM'|'AN'|'AO'|'AQ'|'AR'|'AS'|'AT'|'AU'|'AW'|'AZ'|'BA'|'BB'|'BD'|'BE'|'BF'|'BG'|'BH'|'BI'|'BJ'|'BL'|'BM'|'BN'|'BO'|'BR'|'BS'|'BT'|'BW'|'BY'|'BZ'|'CA'|'CC'|'CD'|'CF'|'CG'|'CH'|'CI'|'CK'|'CL'|'CM'|'CN'|'CO'|'CR'|'CU'|'CV'|'CX'|'CY'|'CZ'|'DE'|'DJ'|'DK'|'DM'|'DO'|'DZ'|'EC'|'EE'|'EG'|'ER'|'ES'|'ET'|'FI'|'FJ'|'FK'|'FM'|'FO'|'FR'|'GA'|'GB'|'GD'|'GE'|'GH'|'GI'|'GL'|'GM'|'GN'|'GQ'|'GR'|'GT'|'GU'|'GW'|'GY'|'HK'|'HN'|'HR'|'HT'|'HU'|'ID'|'IE'|'IL'|'IM'|'IN'|'IQ'|'IR'|'IS'|'IT'|'JM'|'JO'|'JP'|'KE'|'KG'|'KH'|'KI'|'KM'|'KN'|'KP'|'KR'|'KW'|'KY'|'KZ'|'LA'|'LB'|'LC'|'LI'|'LK'|'LR'|'LS'|'LT'|'LU'|'LV'|'LY'|'MA'|'MC'|'MD'|'ME'|'MF'|'MG'|'MH'|'MK'|'ML'|'MM'|'MN'|'MO'|'MP'|'MR'|'MS'|'MT'|'MU'|'MV'|'MW'|'MX'|'MY'|'MZ'|'NA'|'NC'|'NE'|'NG'|'NI'|'NL'|'NO'|'NP'|'NR'|'NU'|'NZ'|'OM'|'PA'|'PE'|'PF'|'PG'|'PH'|'PK'|'PL'|'PM'|'PN'|'PR'|'PT'|'PW'|'PY'|'QA'|'RO'|'RS'|'RU'|'RW'|'SA'|'SB'|'SC'|'SD'|'SE'|'SG'|'SH'|'SI'|'SK'|'SL'|'SM'|'SN'|'SO'|'SR'|'ST'|'SV'|'SY'|'SZ'|'TC'|'TD'|'TG'|'TH'|'TJ'|'TK'|'TL'|'TM'|'TN'|'TO'|'TR'|'TT'|'TV'|'TW'|'TZ'|'UA'|'UG'|'US'|'UY'|'UZ'|'VA'|'VC'|'VE'|'VG'|'VI'|'VN'|'VU'|'WF'|'WS'|'YE'|'YT'|'ZA'|'ZM'|'ZW',
                'ZipCode': 'string',
                'PhoneNumber': 'string',
                'Email': 'string',
                'Fax': 'string',
                'ExtraParams': [
                  {
                    'Name': 'DUNS_NUMBER'|'BRAND_NUMBER'|'BIRTH_DEPARTMENT'|'BIRTH_DATE_IN_YYYY_MM_DD'|'BIRTH_COUNTRY'|'BIRTH_CITY'|'DOCUMENT_NUMBER'|'AU_ID_NUMBER'|'AU_ID_TYPE'|'CA_LEGAL_TYPE'|'CA_BUSINESS_ENTITY_TYPE'|'ES_IDENTIFICATION'|'ES_IDENTIFICATION_TYPE'|'ES_LEGAL_FORM'|'FI_BUSINESS_NUMBER'|'FI_ID_NUMBER'|'IT_PIN'|'RU_PASSPORT_DATA'|'SE_ID_NUMBER'|'SG_ID_NUMBER'|'VAT_NUMBER',
                    'Value': 'string'
                  },
                ]
              },
              'TechContact': {
                'FirstName': 'string',
                'LastName': 'string',
                'ContactType': 'PERSON'|'COMPANY'|'ASSOCIATION'|'PUBLIC_BODY'|'RESELLER',
                'OrganizationName': 'string',
                'AddressLine1': 'string',
                'AddressLine2': 'string',
                'City': 'string',
                'State': 'string',
                'CountryCode': 'AD'|'AE'|'AF'|'AG'|'AI'|'AL'|'AM'|'AN'|'AO'|'AQ'|'AR'|'AS'|'AT'|'AU'|'AW'|'AZ'|'BA'|'BB'|'BD'|'BE'|'BF'|'BG'|'BH'|'BI'|'BJ'|'BL'|'BM'|'BN'|'BO'|'BR'|'BS'|'BT'|'BW'|'BY'|'BZ'|'CA'|'CC'|'CD'|'CF'|'CG'|'CH'|'CI'|'CK'|'CL'|'CM'|'CN'|'CO'|'CR'|'CU'|'CV'|'CX'|'CY'|'CZ'|'DE'|'DJ'|'DK'|'DM'|'DO'|'DZ'|'EC'|'EE'|'EG'|'ER'|'ES'|'ET'|'FI'|'FJ'|'FK'|'FM'|'FO'|'FR'|'GA'|'GB'|'GD'|'GE'|'GH'|'GI'|'GL'|'GM'|'GN'|'GQ'|'GR'|'GT'|'GU'|'GW'|'GY'|'HK'|'HN'|'HR'|'HT'|'HU'|'ID'|'IE'|'IL'|'IM'|'IN'|'IQ'|'IR'|'IS'|'IT'|'JM'|'JO'|'JP'|'KE'|'KG'|'KH'|'KI'|'KM'|'KN'|'KP'|'KR'|'KW'|'KY'|'KZ'|'LA'|'LB'|'LC'|'LI'|'LK'|'LR'|'LS'|'LT'|'LU'|'LV'|'LY'|'MA'|'MC'|'MD'|'ME'|'MF'|'MG'|'MH'|'MK'|'ML'|'MM'|'MN'|'MO'|'MP'|'MR'|'MS'|'MT'|'MU'|'MV'|'MW'|'MX'|'MY'|'MZ'|'NA'|'NC'|'NE'|'NG'|'NI'|'NL'|'NO'|'NP'|'NR'|'NU'|'NZ'|'OM'|'PA'|'PE'|'PF'|'PG'|'PH'|'PK'|'PL'|'PM'|'PN'|'PR'|'PT'|'PW'|'PY'|'QA'|'RO'|'RS'|'RU'|'RW'|'SA'|'SB'|'SC'|'SD'|'SE'|'SG'|'SH'|'SI'|'SK'|'SL'|'SM'|'SN'|'SO'|'SR'|'ST'|'SV'|'SY'|'SZ'|'TC'|'TD'|'TG'|'TH'|'TJ'|'TK'|'TL'|'TM'|'TN'|'TO'|'TR'|'TT'|'TV'|'TW'|'TZ'|'UA'|'UG'|'US'|'UY'|'UZ'|'VA'|'VC'|'VE'|'VG'|'VI'|'VN'|'VU'|'WF'|'WS'|'YE'|'YT'|'ZA'|'ZM'|'ZW',
                'ZipCode': 'string',
                'PhoneNumber': 'string',
                'Email': 'string',
                'Fax': 'string',
                'ExtraParams': [
                  {
                    'Name': 'DUNS_NUMBER'|'BRAND_NUMBER'|'BIRTH_DEPARTMENT'|'BIRTH_DATE_IN_YYYY_MM_DD'|'BIRTH_COUNTRY'|'BIRTH_CITY'|'DOCUMENT_NUMBER'|'AU_ID_NUMBER'|'AU_ID_TYPE'|'CA_LEGAL_TYPE'|'CA_BUSINESS_ENTITY_TYPE'|'ES_IDENTIFICATION'|'ES_IDENTIFICATION_TYPE'|'ES_LEGAL_FORM'|'FI_BUSINESS_NUMBER'|'FI_ID_NUMBER'|'IT_PIN'|'RU_PASSPORT_DATA'|'SE_ID_NUMBER'|'SG_ID_NUMBER'|'VAT_NUMBER',
                    'Value': 'string'
                  },
                ]
              },
              'AdminPrivacy': True|False,
              'RegistrantPrivacy': True|False,
              'TechPrivacy': True|False,
              'RegistrarName': 'string',
              'WhoIsServer': 'string',
              'RegistrarUrl': 'string',
              'AbuseContactEmail': 'string',
              'AbuseContactPhone': 'string',
              'RegistryDomainId': 'string',
              'CreationDate': datetime(2015, 1, 1),
              'UpdatedDate': datetime(2015, 1, 1),
              'ExpirationDate': datetime(2015, 1, 1),
              'Reseller': 'string',
              'DnsSec': 'string',
              'StatusList': [
                'string',
              ]
            }
            Response Structure
            (dict) --The GetDomainDetail response includes the following elements.
            DomainName (string) --The name of a domain.
            Type: String
            Nameservers (list) --The name of the domain.
            Type: String
            (dict) --Nameserver includes the following elements.
            Name (string) --The fully qualified host name of the name server.
            Type: String
            Constraint: Maximum 255 characterss
            Parent: Nameservers
            GlueIps (list) --Glue IP address of a name server entry. Glue IP addresses are required only when the name of the name server is a subdomain of the domain. For example, if your domain is example.com and the name server for the domain is ns.example.com, you need to specify the IP address for ns.example.com.
            Type: List of IP addresses.
            Constraints: The list can contain only one IPv4 and one IPv6 address.
            Parent: Nameservers
            (string) --
            
            AutoRenew (boolean) --Specifies whether the domain registration is set to renew automatically.
            Type: Boolean
            AdminContact (dict) --Provides details about the domain administrative contact.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) --Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) --Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            RegistrantContact (dict) --Provides details about the domain registrant.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) --Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) --Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            TechContact (dict) --Provides details about the domain technical contact.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) --Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) --Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            AdminPrivacy (boolean) --Specifies whether contact information for the admin contact is concealed from WHOIS queries. If the value is true , WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            RegistrantPrivacy (boolean) --Specifies whether contact information for the registrant contact is concealed from WHOIS queries. If the value is true , WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            TechPrivacy (boolean) --Specifies whether contact information for the tech contact is concealed from WHOIS queries. If the value is true , WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            RegistrarName (string) --Name of the registrar of the domain as identified in the registry. Amazon Route 53 domains are registered by registrar Gandi. The value is 'GANDI SAS' .
            Type: String
            WhoIsServer (string) --The fully qualified name of the WHOIS server that can answer the WHOIS query for the domain.
            Type: String
            RegistrarUrl (string) --Web address of the registrar.
            Type: String
            AbuseContactEmail (string) --Email address to contact to report incorrect contact information for a domain, to report that the domain is being used to send spam, to report that someone is cybersquatting on a domain name, or report some other type of abuse.
            Type: String
            AbuseContactPhone (string) --Phone number for reporting abuse.
            Type: String
            RegistryDomainId (string) --Reserved for future use.
            CreationDate (datetime) --The date when the domain was created as found in the response to a WHOIS query. The date format is Unix time.
            UpdatedDate (datetime) --The last updated date of the domain as found in the response to a WHOIS query. The date format is Unix time.
            ExpirationDate (datetime) --The date when the registration for the domain is set to expire. The date format is Unix time.
            Reseller (string) --Reseller of the domain. Domains registered or transferred using Amazon Route 53 domains will have 'Amazon' as the reseller.
            Type: String
            DnsSec (string) --Reserved for future use.
            StatusList (list) --An array of domain name status codes, also known as Extensible Provisioning Protocol (EPP) status codes.
            ICANN, the organization that maintains a central database of domain names, has developed a set of domain name status codes that tell you the status of a variety of operations on a domain name, for example, registering a domain name, transferring a domain name to another registrar, renewing the registration for a domain name, and so on. All registrars use this same set of status codes.
            For a current list of domain name status codes and an explanation of what each code means, go to the ICANN website and search for epp status codes . (Search on the ICANN website; web searches sometimes return an old version of the document.)
            Type: Array of String
            (string) --
            
            
    :type DomainName: string
    """
    pass

def get_domain_suggestions(DomainName=None, SuggestionCount=None, OnlyAvailable=None):
    """
    :param DomainName: [REQUIRED]
    :type DomainName: string
    :param SuggestionCount: [REQUIRED]
    :type SuggestionCount: integer
    :param OnlyAvailable: [REQUIRED]
    :type OnlyAvailable: boolean
    """
    pass

def get_operation_detail(OperationId=None):
    """
    :param OperationId: [REQUIRED]
            The identifier for the operation for which you want to get the status. Amazon Route 53 returned the identifier in the response to the original request.
            Type: String
            Default: None
            Required: Yes
            Return typedict
            ReturnsResponse Syntax{
              'OperationId': 'string',
              'Status': 'SUBMITTED'|'IN_PROGRESS'|'ERROR'|'SUCCESSFUL'|'FAILED',
              'Message': 'string',
              'DomainName': 'string',
              'Type': 'REGISTER_DOMAIN'|'DELETE_DOMAIN'|'TRANSFER_IN_DOMAIN'|'UPDATE_DOMAIN_CONTACT'|'UPDATE_NAMESERVER'|'CHANGE_PRIVACY_PROTECTION'|'DOMAIN_LOCK',
              'SubmittedDate': datetime(2015, 1, 1)
            }
            Response Structure
            (dict) --The GetOperationDetail response includes the following elements.
            OperationId (string) --The identifier for the operation.
            Type: String
            Status (string) --The current status of the requested operation in the system.
            Type: String
            Message (string) --Detailed information on the status including possible errors.
            Type: String
            DomainName (string) --The name of a domain.
            Type: String
            Type (string) --The type of operation that was requested.
            Type: String
            SubmittedDate (datetime) --The date when the request was submitted.
            
            
    :type OperationId: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_domains(Marker=None, MaxItems=None):
    """
    :param Marker: For an initial request for a list of domains, omit this element. If the number of domains that are associated with the current AWS account is greater than the value that you specified for MaxItems , you can use Marker to return additional domains. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element.
            Type: String
            Default: None
            Constraints: The marker must match the value specified in the previous request.
            Required: No
            
    :type Marker: string
    :param MaxItems: Number of domains to be returned.
            Type: Integer
            Default: 20
            Constraints: A numeral between 1 and 100.
            Required: No
            
    :type MaxItems: integer
    """
    pass

def list_operations(Marker=None, MaxItems=None):
    """
    :param Marker: For an initial request for a list of operations, omit this element. If the number of operations that are not yet complete is greater than the value that you specified for MaxItems , you can use Marker to return additional operations. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element.
            Type: String
            Default: None
            Required: No
            
    :type Marker: string
    :param MaxItems: Number of domains to be returned.
            Type: Integer
            Default: 20
            Constraints: A value between 1 and 100.
            Required: No
            
    :type MaxItems: integer
    """
    pass

def list_tags_for_domain(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The domain for which you want to get a list of tags.
            Return typedict
            ReturnsResponse Syntax{
              'TagList': [
                {
                  'Key': 'string',
                  'Value': 'string'
                },
              ]
            }
            Response Structure
            (dict) --The ListTagsForDomain response includes the following elements.
            TagList (list) --A list of the tags that are associated with the specified domain.
            Type: A complex type containing a list of tags
            Each tag includes the following elements.
            Key The key (name) of a tag. Type: String
            Value The value of a tag. Type: String
            (dict) --Each tag includes the following elements.
            Key (string) --The key (name) of a tag.
            Type: String
            Default: None
            Valid values: A-Z, a-z, 0-9, space, '.:/=+-@'
            Constraints: Each key can be 1-128 characters long.
            Required: Yes
            Value (string) --The value of a tag.
            Type: String
            Default: None
            Valid values: A-Z, a-z, 0-9, space, '.:/=+-@'
            Constraints: Each value can be 0-256 characters long.
            Required: Yes
            
            
            
    :type DomainName: string
    """
    pass

def register_domain(DomainName=None, IdnLangCode=None, DurationInYears=None, AutoRenew=None, AdminContact=None, RegistrantContact=None, TechContact=None, PrivacyProtectAdminContact=None, PrivacyProtectRegistrantContact=None, PrivacyProtectTechContact=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            
    :type DomainName: string
    :param IdnLangCode: Reserved for future use.
    :type IdnLangCode: string
    :param DurationInYears: [REQUIRED]
            The number of years the domain will be registered. Domains are registered for a minimum of one year. The maximum period depends on the top-level domain.
            Type: Integer
            Default: 1
            Valid values: Integer from 1 to 10
            Required: Yes
            
    :type DurationInYears: integer
    :param AutoRenew: Indicates whether the domain will be automatically renewed (true ) or not (false ). Autorenewal only takes effect after the account is charged.
            Type: Boolean
            Valid values: true | false
            Default: true
            Required: No
            
    :type AutoRenew: boolean
    :param AdminContact: [REQUIRED]
            Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type AdminContact: dict
    :param RegistrantContact: [REQUIRED]
            Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type RegistrantContact: dict
    :param TechContact: [REQUIRED]
            Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type TechContact: dict
    :param PrivacyProtectAdminContact: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: true
            Valid values: true | false
            Required: No
            
    :type PrivacyProtectAdminContact: boolean
    :param PrivacyProtectRegistrantContact: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: true
            Valid values: true | false
            Required: No
            
    :type PrivacyProtectRegistrantContact: boolean
    :param PrivacyProtectTechContact: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: true
            Valid values: true | false
            Required: No
            
    :type PrivacyProtectTechContact: boolean
    """
    pass

def renew_domain(DomainName=None, DurationInYears=None, CurrentExpiryYear=None):
    """
    :param DomainName: [REQUIRED]
    :type DomainName: string
    :param DurationInYears: The number of years that you want to renew the domain for. The maximum number of years depends on the top-level domain. For the range of valid values for your domain, see Domains that You Can Register with Amazon Route 53 in the Amazon Route 53 documentation.
            Type: Integer
            Default: 1
            Valid values: Integer from 1 to 10
            Required: No
            
    :type DurationInYears: integer
    :param CurrentExpiryYear: [REQUIRED]
            The year when the registration for the domain is set to expire. This value must match the current expiration date for the domain.
            Type: Integer
            Default: None
            Valid values: Integer
            Required: Yes
            
    :type CurrentExpiryYear: integer
    """
    pass

def resend_contact_reachability_email(domainName=None):
    """
    :param domainName: The name of the domain for which you want Amazon Route 53 to resend a confirmation email to the registrant contact.
            Type: String
            Default: None
            Required: Yes
            Return typedict
            ReturnsResponse Syntax{
              'domainName': 'string',
              'emailAddress': 'string',
              'isAlreadyVerified': True|False
            }
            Response Structure
            (dict) --
            domainName (string) --The domain name for which you requested a confirmation email.
            emailAddress (string) --The email address for the registrant contact at the time that we sent the verification email.
            isAlreadyVerified (boolean) --True if the email address for the registrant contact has already been verified, and false otherwise. If the email address has already been verified, we don't send another confirmation email.
            
            
    :type domainName: string
    """
    pass

def retrieve_domain_auth_code(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            Return typedict
            ReturnsResponse Syntax{
              'AuthCode': 'string'
            }
            Response Structure
            (dict) --The RetrieveDomainAuthCode response includes the following element.
            AuthCode (string) --The authorization code for the domain.
            Type: String
            
            
    :type DomainName: string
    """
    pass

def transfer_domain(DomainName=None, IdnLangCode=None, DurationInYears=None, Nameservers=None, AuthCode=None, AutoRenew=None, AdminContact=None, RegistrantContact=None, TechContact=None, PrivacyProtectAdminContact=None, PrivacyProtectRegistrantContact=None, PrivacyProtectTechContact=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            
    :type DomainName: string
    :param IdnLangCode: Reserved for future use.
    :type IdnLangCode: string
    :param DurationInYears: [REQUIRED]
            The number of years the domain will be registered. Domains are registered for a minimum of one year. The maximum period depends on the top-level domain.
            Type: Integer
            Default: 1
            Valid values: Integer from 1 to 10
            Required: Yes
            
    :type DurationInYears: integer
    :param Nameservers: Contains details for the host and glue IP addresses.
            Type: Complex
            Children: GlueIps , Name
            Required: No
            (dict) --Nameserver includes the following elements.
            Name (string) -- [REQUIRED]The fully qualified host name of the name server.
            Type: String
            Constraint: Maximum 255 characterss
            Parent: Nameservers
            GlueIps (list) --Glue IP address of a name server entry. Glue IP addresses are required only when the name of the name server is a subdomain of the domain. For example, if your domain is example.com and the name server for the domain is ns.example.com, you need to specify the IP address for ns.example.com.
            Type: List of IP addresses.
            Constraints: The list can contain only one IPv4 and one IPv6 address.
            Parent: Nameservers
            (string) --
            
            
    :type Nameservers: list
    :param AuthCode: The authorization code for the domain. You get this value from the current registrar.
            Type: String
            Required: Yes
            
    :type AuthCode: string
    :param AutoRenew: Indicates whether the domain will be automatically renewed (true) or not (false). Autorenewal only takes effect after the account is charged.
            Type: Boolean
            Valid values: true | false
            Default: true
            Required: No
            
    :type AutoRenew: boolean
    :param AdminContact: [REQUIRED]
            Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type AdminContact: dict
    :param RegistrantContact: [REQUIRED]
            Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type RegistrantContact: dict
    :param TechContact: [REQUIRED]
            Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type TechContact: dict
    :param PrivacyProtectAdminContact: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: true
            Valid values: true | false
            Required: No
            
    :type PrivacyProtectAdminContact: boolean
    :param PrivacyProtectRegistrantContact: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: true
            Valid values: true | false
            Required: No
            
    :type PrivacyProtectRegistrantContact: boolean
    :param PrivacyProtectTechContact: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: true
            Valid values: true | false
            Required: No
            
    :type PrivacyProtectTechContact: boolean
    """
    pass

def update_domain_contact(DomainName=None, AdminContact=None, RegistrantContact=None, TechContact=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            
    :type DomainName: string
    :param AdminContact: Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type AdminContact: dict
    :param RegistrantContact: Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type RegistrantContact: dict
    :param TechContact: Provides detailed contact information.
            Type: Complex
            Children: FirstName , MiddleName , LastName , ContactType , OrganizationName , AddressLine1 , AddressLine2 , City , State , CountryCode , ZipCode , PhoneNumber , Email , Fax , ExtraParams
            Required: Yes
            FirstName (string) --First name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            LastName (string) --Last name of contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ContactType (string) --Indicates whether the contact is a person, company, association, or public organization. If you choose an option other than PERSON , you must enter an organization name, and you cant enable privacy protection for the contact.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Valid values: PERSON | COMPANY | ASSOCIATION | PUBLIC_BODY
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            OrganizationName (string) --Name of the organization for contact types other than PERSON .
            Type: String
            Default: None
            Constraints: Maximum 255 characters. Contact type must not be PERSON .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            AddressLine1 (string) --First line of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            AddressLine2 (string) --Second line of contacts address, if any.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            City (string) --The city of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            State (string) --The state or province of the contacts city.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            CountryCode (string) --Code for the country of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            ZipCode (string) --The zip or postal code of the contacts address.
            Type: String
            Default: None
            Constraints: Maximum 255 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            PhoneNumber (string) --The phone number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code>]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Email (string) --Email address of the contact.
            Type: String
            Default: None
            Constraints: Maximum 254 characters.
            Parents: RegistrantContact , AdminContact , TechContact
            Required: Yes
            Fax (string) --Fax number of the contact.
            Type: String
            Default: None
            Constraints: Phone number must be specified in the format '+[country dialing code].[number including any area code]'. For example, a US phone number might appear as '+1.1234567890' .
            Parents: RegistrantContact , AdminContact , TechContact
            Required: No
            ExtraParams (list) --A list of name-value pairs for parameters required by certain top-level domains.
            Type: Complex
            Default: None
            Parents: RegistrantContact , AdminContact , TechContact
            Children: Name , Value
            Required: No
            (dict) --ExtraParam includes the following elements.
            Name (string) -- [REQUIRED]Name of the additional parameter required by the top-level domain.
            Type: String
            Default: None
            Valid values: DUNS_NUMBER | BRAND_NUMBER | BIRTH_DEPARTMENT | BIRTH_DATE_IN_YYYY_MM_DD | BIRTH_COUNTRY | BIRTH_CITY | DOCUMENT_NUMBER | AU_ID_NUMBER | AU_ID_TYPE | CA_LEGAL_TYPE | CA_BUSINESS_ENTITY_TYPE |ES_IDENTIFICATION | ES_IDENTIFICATION_TYPE | ES_LEGAL_FORM | FI_BUSINESS_NUMBER | FI_ID_NUMBER | IT_PIN | RU_PASSPORT_DATA | SE_ID_NUMBER | SG_ID_NUMBER | VAT_NUMBER
            Parent: ExtraParams
            Required: Yes
            Value (string) -- [REQUIRED]Values corresponding to the additional parameter names required by some top-level domains.
            Type: String
            Default: None
            Constraints: Maximum 2048 characters.
            Parent: ExtraParams
            Required: Yes
            
            
    :type TechContact: dict
    """
    pass

def update_domain_contact_privacy(DomainName=None, AdminPrivacy=None, RegistrantPrivacy=None, TechPrivacy=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            
    :type DomainName: string
    :param AdminPrivacy: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: None
            Valid values: true | false
            Required: No
            
    :type AdminPrivacy: boolean
    :param RegistrantPrivacy: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: None
            Valid values: true | false
            Required: No
            
    :type RegistrantPrivacy: boolean
    :param TechPrivacy: Whether you want to conceal contact information from WHOIS queries. If you specify true, WHOIS ('who is') queries will return contact information for our registrar partner, Gandi, instead of the contact information that you enter.
            Type: Boolean
            Default: None
            Valid values: true | false
            Required: No
            
    :type TechPrivacy: boolean
    """
    pass

def update_domain_nameservers(DomainName=None, FIAuthKey=None, Nameservers=None):
    """
    :param DomainName: [REQUIRED]
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Internationalized Domain Names are not supported.
            Required: Yes
            
    :type DomainName: string
    :param FIAuthKey: The authorization key for .fi domains
    :type FIAuthKey: string
    :param Nameservers: [REQUIRED]
            A list of new name servers for the domain.
            Type: Complex
            Children: Name , GlueIps
            Required: Yes
            (dict) --Nameserver includes the following elements.
            Name (string) -- [REQUIRED]The fully qualified host name of the name server.
            Type: String
            Constraint: Maximum 255 characterss
            Parent: Nameservers
            GlueIps (list) --Glue IP address of a name server entry. Glue IP addresses are required only when the name of the name server is a subdomain of the domain. For example, if your domain is example.com and the name server for the domain is ns.example.com, you need to specify the IP address for ns.example.com.
            Type: List of IP addresses.
            Constraints: The list can contain only one IPv4 and one IPv6 address.
            Parent: Nameservers
            (string) --
            
            
    :type Nameservers: list
    """
    pass

def update_tags_for_domain(DomainName=None, TagsToUpdate=None):
    """
    :param DomainName: [REQUIRED]
            The domain for which you want to add or update tags.
            The name of a domain.
            Type: String
            Default: None
            Constraints: The domain name can contain only the letters a through z, the numbers 0 through 9, and hyphen (-). Hyphens are allowed only when theyre surrounded by letters, numbers, or other hyphens. You cant specify a hyphen at the beginning or end of a label. To specify an Internationalized Domain Name, you must convert the name to Punycode.
            Required: Yes
            
    :type DomainName: string
    :param TagsToUpdate: A list of the tag keys and values that you want to add or update. If you specify a key that already exists, the corresponding value will be replaced.
            Type: A complex type containing a list of tags
            Default: None
            Required: No
            '>
            Each tag includes the following elements:
            Key The key (name) of a tag. Type: String Default: None Valid values: Unicode characters including alphanumeric, space, and '.:/=+-@' Constraints: Each key can be 1-128 characters long. Required: Yes
            Value The value of a tag. Type: String Default: None Valid values: Unicode characters including alphanumeric, space, and '.:/=+-@' Constraints: Each value can be 0-256 characters long. Required: Yes
            (dict) --Each tag includes the following elements.
            Key (string) --The key (name) of a tag.
            Type: String
            Default: None
            Valid values: A-Z, a-z, 0-9, space, '.:/=+-@'
            Constraints: Each key can be 1-128 characters long.
            Required: Yes
            Value (string) --The value of a tag.
            Type: String
            Default: None
            Valid values: A-Z, a-z, 0-9, space, '.:/=+-@'
            Constraints: Each value can be 0-256 characters long.
            Required: Yes
            
            
    :type TagsToUpdate: list
    """
    pass

def view_billing(Start=None, End=None, Marker=None, MaxItems=None):
    """
    :param Start: The beginning date and time for the time period for which you want a list of billing records. Specify the date in Unix time format.
            Type: Double
            Default: None
            Required: Yes
            
    :type Start: datetime
    :param End: The end date and time for the time period for which you want a list of billing records. Specify the date in Unix time format.
            Type: Double
            Default: None
            Required: Yes
            
    :type End: datetime
    :param Marker: For an initial request for a list of billing records, omit this element. If the number of billing records that are associated with the current AWS account during the specified period is greater than the value that you specified for MaxItems , you can use Marker to return additional billing records. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element.
            Type: String
            Default: None
            Constraints: The marker must match the value of NextPageMarker that was returned in the previous response.
            Required: No
            
    :type Marker: string
    :param MaxItems: The number of billing records to be returned.
            Type: Integer
            Default: 20
            Constraints: A value between 1 and 100.
            Required: No
            
    :type MaxItems: integer
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def cancel_job(JobId=None):
    """
    :param JobId: [REQUIRED]
            The 39 character job ID for the job that you want to cancel, for example JID123e4567-e89b-12d3-a456-426655440000 .
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --
            
    :type JobId: string
    """
    pass

def create_address(Address=None):
    """
    :param Address: [REQUIRED]
            The address that you want the Snowball shipped to.
            AddressId (string) --The unique ID for an address.
            Name (string) --The name of a person to receive a Snowball at an address.
            Company (string) --The name of the company to receive a Snowball at an address.
            Street1 (string) --The first line in a street address that a Snowball is to be delivered to.
            Street2 (string) --The second line in a street address that a Snowball is to be delivered to.
            Street3 (string) --The third line in a street address that a Snowball is to be delivered to.
            City (string) --The city in an address that a Snowball is to be delivered to.
            StateOrProvince (string) --The state or province in an address that a Snowball is to be delivered to.
            PrefectureOrDistrict (string) --The prefecture or district in an address that a Snowball is to be delivered to.
            Landmark (string) --A landmark listed in an address that a Snowball is to be delivered to.
            Country (string) --The country in an address that a Snowball is to be delivered to.
            PostalCode (string) --The postal code in an address that a Snowball is to be delivered to.
            PhoneNumber (string) --The phone number associated with an address that a Snowball is to be delivered to.
            Return typedict
            ReturnsResponse Syntax{
              'AddressId': 'string'
            }
            Response Structure
            (dict) --
            AddressId (string) --The automatically generated ID for a specific address. You'll use this ID when you create a job to specify which address you want the Snowball for that job shipped to.
            
            
    :type Address: dict
    """
    pass

def create_job(JobType=None, Resources=None, Description=None, AddressId=None, KmsKeyARN=None, RoleARN=None, SnowballCapacityPreference=None, ShippingOption=None, Notification=None):
    """
    :param JobType: [REQUIRED]
            Defines the type of job that you're creating.
            
    :type JobType: string
    :param Resources: [REQUIRED]
            Defines the Amazon S3 buckets associated with this job.
            With IMPORT jobs, you specify the bucket or buckets that your transferred data will be imported into.
            With EXPORT jobs, you specify the bucket or buckets that your transferred data will be exported from. Optionally, you can also specify a KeyRange value. If you choose to export a range, you define the length of the range by providing either an inclusive BeginMarker value, an inclusive EndMarker value, or both. Ranges are UTF-8 binary sorted.
            S3Resources (list) --An array of S3Resource objects.
            (dict) --Each S3Resource object represents an Amazon S3 bucket that your transferred data will be exported from or imported into. For export jobs, this object can have an optional KeyRange value. The length of the range is defined at job creation, and has either an inclusive BeginMarker , an inclusive EndMarker , or both. Ranges are UTF-8 binary sorted.
            BucketArn (string) --The Amazon Resource Name (ARN) of an Amazon S3 bucket.
            KeyRange (dict) --For export jobs, you can provide an optional KeyRange within a specific Amazon S3 bucket. The length of the range is defined at job creation, and has either an inclusive BeginMarker , an inclusive EndMarker , or both. Ranges are UTF-8 binary sorted.
            BeginMarker (string) --The key that starts an optional key range for an export job. Ranges are inclusive and UTF-8 binary sorted.
            EndMarker (string) --The key that ends an optional key range for an export job. Ranges are inclusive and UTF-8 binary sorted.
            
            
            
    :type Resources: dict
    :param Description: Defines an optional description of this specific job, for example Important Photos 2016-08-11 .
    :type Description: string
    :param AddressId: [REQUIRED]
            The ID for the address that you want the Snowball shipped to.
            
    :type AddressId: string
    :param KmsKeyARN: The KmsKeyARN that you want to associate with this job. KmsKeyARN s are created using the CreateKey AWS Key Management Service (KMS) API action.
    :type KmsKeyARN: string
    :param RoleARN: [REQUIRED]
            The RoleARN that you want to associate with this job. RoleArn s are created using the CreateRole AWS Identity and Access Management (IAM) API action.
            
    :type RoleARN: string
    :param SnowballCapacityPreference: If your job is being created in one of the US regions, you have the option of specifying what size Snowball you'd like for this job. In all other regions, Snowballs come with 80 TB in storage capacity.
    :type SnowballCapacityPreference: string
    :param ShippingOption: [REQUIRED]
            The shipping speed for this job. Note that this speed does not dictate how soon you'll get the Snowball, rather it represents how quickly the Snowball moves to its destination while in transit. Regional shipping speeds are as follows:
            In Australia, you have access to express shipping. Typically, Snowballs shipped express are delivered in about a day.
            In the European Union (EU), you have access to express shipping. Typically, Snowballs shipped express are delivered in about a day. In addition, most countries in the EU have access to standard shipping, which typically takes less than a week, one way.
            In India, Snowballs are delivered in one to seven days.
            In the US, you have access to one-day shipping and two-day shipping.
            
    :type ShippingOption: string
    :param Notification: Defines the Amazon Simple Notification Service (Amazon SNS) notification settings for this job.
            SnsTopicARN (string) --The new SNS TopicArn that you want to associate with this job. You can create Amazon Resource Names (ARNs) for topics by using the CreateTopic Amazon SNS API action.
            Note that you can subscribe email addresses to an Amazon SNS topic through the AWS Management Console, or by using the Subscribe AWS Simple Notification Service (SNS) API action.
            JobStatesToNotify (list) --The list of job states that will trigger a notification for this job.
            (string) --
            NotifyAll (boolean) --Any change in job state will trigger a notification for this job.
            
    :type Notification: dict
    """
    pass

def describe_address(AddressId=None):
    """
    :param AddressId: [REQUIRED]
            The automatically generated ID for a specific address.
            Return typedict
            ReturnsResponse Syntax{
              'Address': {
                'AddressId': 'string',
                'Name': 'string',
                'Company': 'string',
                'Street1': 'string',
                'Street2': 'string',
                'Street3': 'string',
                'City': 'string',
                'StateOrProvince': 'string',
                'PrefectureOrDistrict': 'string',
                'Landmark': 'string',
                'Country': 'string',
                'PostalCode': 'string',
                'PhoneNumber': 'string'
              }
            }
            Response Structure
            (dict) --
            Address (dict) --The address that you want the Snowball or Snowballs associated with a specific job to be shipped to.
            AddressId (string) --The unique ID for an address.
            Name (string) --The name of a person to receive a Snowball at an address.
            Company (string) --The name of the company to receive a Snowball at an address.
            Street1 (string) --The first line in a street address that a Snowball is to be delivered to.
            Street2 (string) --The second line in a street address that a Snowball is to be delivered to.
            Street3 (string) --The third line in a street address that a Snowball is to be delivered to.
            City (string) --The city in an address that a Snowball is to be delivered to.
            StateOrProvince (string) --The state or province in an address that a Snowball is to be delivered to.
            PrefectureOrDistrict (string) --The prefecture or district in an address that a Snowball is to be delivered to.
            Landmark (string) --A landmark listed in an address that a Snowball is to be delivered to.
            Country (string) --The country in an address that a Snowball is to be delivered to.
            PostalCode (string) --The postal code in an address that a Snowball is to be delivered to.
            PhoneNumber (string) --The phone number associated with an address that a Snowball is to be delivered to.
            
            
            
    :type AddressId: string
    """
    pass

def describe_addresses(MaxResults=None, NextToken=None):
    """
    :param MaxResults: The number of ADDRESS objects to return.
    :type MaxResults: integer
    :param NextToken: HTTP requests are stateless. To identify what object comes 'next' in the list of ADDRESS objects, you have the option of specifying a value for NextToken as the starting point for your list of returned addresses.
    :type NextToken: string
    """
    pass

def describe_job(JobId=None):
    """
    :param JobId: [REQUIRED]
            The automatically generated ID for a job, for example JID123e4567-e89b-12d3-a456-426655440000 .
            Return typedict
            ReturnsResponse Syntax{
              'JobMetadata': {
                'JobId': 'string',
                'JobState': 'New'|'PreparingAppliance'|'PreparingShipment'|'InTransitToCustomer'|'WithCustomer'|'InTransitToAWS'|'WithAWS'|'InProgress'|'Complete'|'Cancelled'|'Listing'|'Pending',
                'JobType': 'IMPORT'|'EXPORT',
                'CreationDate': datetime(2015, 1, 1),
                'Resources': {
                  'S3Resources': [
                    {
                      'BucketArn': 'string',
                      'KeyRange': {
                        'BeginMarker': 'string',
                        'EndMarker': 'string'
                      }
                    },
                  ]
                },
                'Description': 'string',
                'KmsKeyARN': 'string',
                'RoleARN': 'string',
                'AddressId': 'string',
                'ShippingDetails': {
                  'ShippingOption': 'SECOND_DAY'|'NEXT_DAY'|'EXPRESS'|'STANDARD',
                  'InboundShipment': {
                    'Status': 'string',
                    'TrackingNumber': 'string'
                  },
                  'OutboundShipment': {
                    'Status': 'string',
                    'TrackingNumber': 'string'
                  }
                },
                'SnowballCapacityPreference': 'T50'|'T80'|'NoPreference',
                'Notification': {
                  'SnsTopicARN': 'string',
                  'JobStatesToNotify': [
                    'New'|'PreparingAppliance'|'PreparingShipment'|'InTransitToCustomer'|'WithCustomer'|'InTransitToAWS'|'WithAWS'|'InProgress'|'Complete'|'Cancelled'|'Listing'|'Pending',
                  ],
                  'NotifyAll': True|False
                },
                'DataTransferProgress': {
                  'BytesTransferred': 123,
                  'ObjectsTransferred': 123,
                  'TotalBytes': 123,
                  'TotalObjects': 123
                },
                'JobLogInfo': {
                  'JobCompletionReportURI': 'string',
                  'JobSuccessLogURI': 'string',
                  'JobFailureLogURI': 'string'
                }
              },
              'SubJobMetadata': [
                {
                  'JobId': 'string',
                  'JobState': 'New'|'PreparingAppliance'|'PreparingShipment'|'InTransitToCustomer'|'WithCustomer'|'InTransitToAWS'|'WithAWS'|'InProgress'|'Complete'|'Cancelled'|'Listing'|'Pending',
                  'JobType': 'IMPORT'|'EXPORT',
                  'CreationDate': datetime(2015, 1, 1),
                  'Resources': {
                    'S3Resources': [
                      {
                        'BucketArn': 'string',
                        'KeyRange': {
                          'BeginMarker': 'string',
                          'EndMarker': 'string'
                        }
                      },
                    ]
                  },
                  'Description': 'string',
                  'KmsKeyARN': 'string',
                  'RoleARN': 'string',
                  'AddressId': 'string',
                  'ShippingDetails': {
                    'ShippingOption': 'SECOND_DAY'|'NEXT_DAY'|'EXPRESS'|'STANDARD',
                    'InboundShipment': {
                      'Status': 'string',
                      'TrackingNumber': 'string'
                    },
                    'OutboundShipment': {
                      'Status': 'string',
                      'TrackingNumber': 'string'
                    }
                  },
                  'SnowballCapacityPreference': 'T50'|'T80'|'NoPreference',
                  'Notification': {
                    'SnsTopicARN': 'string',
                    'JobStatesToNotify': [
                      'New'|'PreparingAppliance'|'PreparingShipment'|'InTransitToCustomer'|'WithCustomer'|'InTransitToAWS'|'WithAWS'|'InProgress'|'Complete'|'Cancelled'|'Listing'|'Pending',
                    ],
                    'NotifyAll': True|False
                  },
                  'DataTransferProgress': {
                    'BytesTransferred': 123,
                    'ObjectsTransferred': 123,
                    'TotalBytes': 123,
                    'TotalObjects': 123
                  },
                  'JobLogInfo': {
                    'JobCompletionReportURI': 'string',
                    'JobSuccessLogURI': 'string',
                    'JobFailureLogURI': 'string'
                  }
                },
              ]
            }
            Response Structure
            (dict) --
            JobMetadata (dict) --Information about a specific job, including shipping information, job status, and other important metadata.
            JobId (string) --The automatically generated ID for a job, for example JID123e4567-e89b-12d3-a456-426655440000 .
            JobState (string) --The current state of the jobs.
            JobType (string) --The type of job.
            CreationDate (datetime) --The creation date for this job.
            Resources (dict) --An array of S3Resource objects. Each S3Resource object represents an Amazon S3 bucket that your transferred data will be exported from or imported into.
            S3Resources (list) --An array of S3Resource objects.
            (dict) --Each S3Resource object represents an Amazon S3 bucket that your transferred data will be exported from or imported into. For export jobs, this object can have an optional KeyRange value. The length of the range is defined at job creation, and has either an inclusive BeginMarker , an inclusive EndMarker , or both. Ranges are UTF-8 binary sorted.
            BucketArn (string) --The Amazon Resource Name (ARN) of an Amazon S3 bucket.
            KeyRange (dict) --For export jobs, you can provide an optional KeyRange within a specific Amazon S3 bucket. The length of the range is defined at job creation, and has either an inclusive BeginMarker , an inclusive EndMarker , or both. Ranges are UTF-8 binary sorted.
            BeginMarker (string) --The key that starts an optional key range for an export job. Ranges are inclusive and UTF-8 binary sorted.
            EndMarker (string) --The key that ends an optional key range for an export job. Ranges are inclusive and UTF-8 binary sorted.
            
            
            Description (string) --The description of the job, provided at job creation.
            KmsKeyARN (string) --The Amazon Resource Name (ARN) for the AWS Key Management Service (AWS KMS) key associated with this job. This ARN was created using the CreateKey API action in AWS KMS.
            RoleARN (string) --The role ARN associated with this job. This ARN was created using the CreateRole API action in AWS Identity and Access Management (IAM).
            AddressId (string) --The ID for the address that you want the Snowball shipped to.
            ShippingDetails (dict) --A job's shipping information, including inbound and outbound tracking numbers and shipping speed options.
            ShippingOption (string) --The shipping speed for a particular job. Note that this speed does not dictate how soon you'll get the Snowball from the job's creation date. This speed represents how quickly it moves to its destination while in transit. Regional shipping speeds are as follows:
            In Australia, you have access to express shipping. Typically, Snowballs shipped express are delivered in about a day.
            In the European Union (EU), you have access to express shipping. Typically, Snowballs shipped express are delivered in about a day. In addition, most countries in the EU have access to standard shipping, which typically takes less than a week, one way.
            In India, Snowballs are delivered in one to seven days.
            In the United States of America (US), you have access to one-day shipping and two-day shipping.
            InboundShipment (dict) --The Status and TrackingNumber values for a Snowball being delivered to the address that you specified for a particular job.
            Status (string) --Status information for a shipment. Valid statuses include NEW , IN_TRANSIT , and DELIVERED .
            TrackingNumber (string) --The tracking number for this job. Using this tracking number with your region's carrier's website, you can track a Snowball as the carrier transports it.
            For India, the carrier is Amazon Logistics. For all other regions, UPS is the carrier.
            OutboundShipment (dict) --The Status and TrackingNumber values for a Snowball being returned to AWS for a particular job.
            Status (string) --Status information for a shipment. Valid statuses include NEW , IN_TRANSIT , and DELIVERED .
            TrackingNumber (string) --The tracking number for this job. Using this tracking number with your region's carrier's website, you can track a Snowball as the carrier transports it.
            For India, the carrier is Amazon Logistics. For all other regions, UPS is the carrier.
            
            SnowballCapacityPreference (string) --The Snowball capacity preference for this job, specified at job creation. In US regions, you can choose between 50 TB and 80 TB Snowballs. All other regions use 80 TB capacity Snowballs.
            Notification (dict) --The Amazon Simple Notification Service (Amazon SNS) notification settings associated with a specific job. The Notification object is returned as a part of the response syntax of the DescribeJob action in the JobMetadata data type.
            SnsTopicARN (string) --The new SNS TopicArn that you want to associate with this job. You can create Amazon Resource Names (ARNs) for topics by using the CreateTopic Amazon SNS API action.
            Note that you can subscribe email addresses to an Amazon SNS topic through the AWS Management Console, or by using the Subscribe AWS Simple Notification Service (SNS) API action.
            JobStatesToNotify (list) --The list of job states that will trigger a notification for this job.
            (string) --
            NotifyAll (boolean) --Any change in job state will trigger a notification for this job.
            DataTransferProgress (dict) --A value that defines the real-time status of a Snowball's data transfer while the appliance is at AWS. Note that this data is only available while a job has a JobState value of InProgress , for both import and export jobs.
            BytesTransferred (integer) --The number of bytes transferred between a Snowball and Amazon S3.
            ObjectsTransferred (integer) --The number of objects transferred between a Snowball and Amazon S3.
            TotalBytes (integer) --The total bytes of data for a transfer between a Snowball and Amazon S3. This value is set to 0 (zero) until all the keys that will be transferred have been listed.
            TotalObjects (integer) --The total number of objects for a transfer between a Snowball and Amazon S3. This value is set to 0 (zero) until all the keys that will be transferred have been listed.
            JobLogInfo (dict) --Links to Amazon S3 presigned URLs for the job report and logs. For import jobs, the PDF job report becomes available at the end of the import process. For export jobs, your job report typically becomes available while the Snowball for your job part is being delivered to you.
            JobCompletionReportURI (string) --A link to an Amazon S3 presigned URL where the job completion report is located.
            JobSuccessLogURI (string) --A link to an Amazon S3 presigned URL where the job success log is located.
            JobFailureLogURI (string) --A link to an Amazon S3 presigned URL where the job failure log is located.
            
            SubJobMetadata (list) --Information about a specific job part (in the case of an export job), including shipping information, job status, and other important metadata.
            (dict) --Contains information about a specific job including shipping information, job status, and other important metadata. This information is returned as a part of the response syntax of the DescribeJob action.
            JobId (string) --The automatically generated ID for a job, for example JID123e4567-e89b-12d3-a456-426655440000 .
            JobState (string) --The current state of the jobs.
            JobType (string) --The type of job.
            CreationDate (datetime) --The creation date for this job.
            Resources (dict) --An array of S3Resource objects. Each S3Resource object represents an Amazon S3 bucket that your transferred data will be exported from or imported into.
            S3Resources (list) --An array of S3Resource objects.
            (dict) --Each S3Resource object represents an Amazon S3 bucket that your transferred data will be exported from or imported into. For export jobs, this object can have an optional KeyRange value. The length of the range is defined at job creation, and has either an inclusive BeginMarker , an inclusive EndMarker , or both. Ranges are UTF-8 binary sorted.
            BucketArn (string) --The Amazon Resource Name (ARN) of an Amazon S3 bucket.
            KeyRange (dict) --For export jobs, you can provide an optional KeyRange within a specific Amazon S3 bucket. The length of the range is defined at job creation, and has either an inclusive BeginMarker , an inclusive EndMarker , or both. Ranges are UTF-8 binary sorted.
            BeginMarker (string) --The key that starts an optional key range for an export job. Ranges are inclusive and UTF-8 binary sorted.
            EndMarker (string) --The key that ends an optional key range for an export job. Ranges are inclusive and UTF-8 binary sorted.
            
            
            Description (string) --The description of the job, provided at job creation.
            KmsKeyARN (string) --The Amazon Resource Name (ARN) for the AWS Key Management Service (AWS KMS) key associated with this job. This ARN was created using the CreateKey API action in AWS KMS.
            RoleARN (string) --The role ARN associated with this job. This ARN was created using the CreateRole API action in AWS Identity and Access Management (IAM).
            AddressId (string) --The ID for the address that you want the Snowball shipped to.
            ShippingDetails (dict) --A job's shipping information, including inbound and outbound tracking numbers and shipping speed options.
            ShippingOption (string) --The shipping speed for a particular job. Note that this speed does not dictate how soon you'll get the Snowball from the job's creation date. This speed represents how quickly it moves to its destination while in transit. Regional shipping speeds are as follows:
            In Australia, you have access to express shipping. Typically, Snowballs shipped express are delivered in about a day.
            In the European Union (EU), you have access to express shipping. Typically, Snowballs shipped express are delivered in about a day. In addition, most countries in the EU have access to standard shipping, which typically takes less than a week, one way.
            In India, Snowballs are delivered in one to seven days.
            In the United States of America (US), you have access to one-day shipping and two-day shipping.
            InboundShipment (dict) --The Status and TrackingNumber values for a Snowball being delivered to the address that you specified for a particular job.
            Status (string) --Status information for a shipment. Valid statuses include NEW , IN_TRANSIT , and DELIVERED .
            TrackingNumber (string) --The tracking number for this job. Using this tracking number with your region's carrier's website, you can track a Snowball as the carrier transports it.
            For India, the carrier is Amazon Logistics. For all other regions, UPS is the carrier.
            OutboundShipment (dict) --The Status and TrackingNumber values for a Snowball being returned to AWS for a particular job.
            Status (string) --Status information for a shipment. Valid statuses include NEW , IN_TRANSIT , and DELIVERED .
            TrackingNumber (string) --The tracking number for this job. Using this tracking number with your region's carrier's website, you can track a Snowball as the carrier transports it.
            For India, the carrier is Amazon Logistics. For all other regions, UPS is the carrier.
            
            SnowballCapacityPreference (string) --The Snowball capacity preference for this job, specified at job creation. In US regions, you can choose between 50 TB and 80 TB Snowballs. All other regions use 80 TB capacity Snowballs.
            Notification (dict) --The Amazon Simple Notification Service (Amazon SNS) notification settings associated with a specific job. The Notification object is returned as a part of the response syntax of the DescribeJob action in the JobMetadata data type.
            SnsTopicARN (string) --The new SNS TopicArn that you want to associate with this job. You can create Amazon Resource Names (ARNs) for topics by using the CreateTopic Amazon SNS API action.
            Note that you can subscribe email addresses to an Amazon SNS topic through the AWS Management Console, or by using the Subscribe AWS Simple Notification Service (SNS) API action.
            JobStatesToNotify (list) --The list of job states that will trigger a notification for this job.
            (string) --
            NotifyAll (boolean) --Any change in job state will trigger a notification for this job.
            DataTransferProgress (dict) --A value that defines the real-time status of a Snowball's data transfer while the appliance is at AWS. Note that this data is only available while a job has a JobState value of InProgress , for both import and export jobs.
            BytesTransferred (integer) --The number of bytes transferred between a Snowball and Amazon S3.
            ObjectsTransferred (integer) --The number of objects transferred between a Snowball and Amazon S3.
            TotalBytes (integer) --The total bytes of data for a transfer between a Snowball and Amazon S3. This value is set to 0 (zero) until all the keys that will be transferred have been listed.
            TotalObjects (integer) --The total number of objects for a transfer between a Snowball and Amazon S3. This value is set to 0 (zero) until all the keys that will be transferred have been listed.
            JobLogInfo (dict) --Links to Amazon S3 presigned URLs for the job report and logs. For import jobs, the PDF job report becomes available at the end of the import process. For export jobs, your job report typically becomes available while the Snowball for your job part is being delivered to you.
            JobCompletionReportURI (string) --A link to an Amazon S3 presigned URL where the job completion report is located.
            JobSuccessLogURI (string) --A link to an Amazon S3 presigned URL where the job success log is located.
            JobFailureLogURI (string) --A link to an Amazon S3 presigned URL where the job failure log is located.
            
            
            
            
    :type JobId: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_job_manifest(JobId=None):
    """
    :param JobId: [REQUIRED]
            The ID for a job that you want to get the manifest file for, for example JID123e4567-e89b-12d3-a456-426655440000 .
            Return typedict
            ReturnsResponse Syntax{
              'ManifestURI': 'string'
            }
            Response Structure
            (dict) --
            ManifestURI (string) --The Amazon S3 presigned URL for the manifest file associated with the specified JobId value.
            
            
    :type JobId: string
    """
    pass

def get_job_unlock_code(JobId=None):
    """
    :param JobId: [REQUIRED]
            The ID for the job that you want to get the UnlockCode value for, for example JID123e4567-e89b-12d3-a456-426655440000 .
            Return typedict
            ReturnsResponse Syntax{
              'UnlockCode': 'string'
            }
            Response Structure
            (dict) --
            UnlockCode (string) --The UnlockCode value for the specified job. The UnlockCode value can be accessed for up to 90 days after the job has been created.
            
            
    :type JobId: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_snowball_usage():
    """
    """
    pass

def get_waiter():
    """
    """
    pass

def list_jobs(MaxResults=None, NextToken=None):
    """
    :param MaxResults: The number of JobListEntry objects to return.
    :type MaxResults: integer
    :param NextToken: HTTP requests are stateless. To identify what object comes 'next' in the list of JobListEntry objects, you have the option of specifying NextToken as the starting point for your returned list.
    :type NextToken: string
    """
    pass

def update_job(JobId=None, RoleARN=None, Notification=None, Resources=None, AddressId=None, ShippingOption=None, Description=None, SnowballCapacityPreference=None):
    """
    :param JobId: [REQUIRED]
            The job ID of the job that you want to update, for example JID123e4567-e89b-12d3-a456-426655440000 .
            
    :type JobId: string
    :param RoleARN: The new role Amazon Resource Name (ARN) that you want to associate with this job. To create a role ARN, use the CreateRole AWS Identity and Access Management (IAM) API action.
    :type RoleARN: string
    :param Notification: The new or updated Notification object.
            SnsTopicARN (string) --The new SNS TopicArn that you want to associate with this job. You can create Amazon Resource Names (ARNs) for topics by using the CreateTopic Amazon SNS API action.
            Note that you can subscribe email addresses to an Amazon SNS topic through the AWS Management Console, or by using the Subscribe AWS Simple Notification Service (SNS) API action.
            JobStatesToNotify (list) --The list of job states that will trigger a notification for this job.
            (string) --
            NotifyAll (boolean) --Any change in job state will trigger a notification for this job.
            
    :type Notification: dict
    :param Resources: The updated S3Resource object (for a single Amazon S3 bucket or key range), or the updated JobResource object (for multiple buckets or key ranges).
            S3Resources (list) --An array of S3Resource objects.
            (dict) --Each S3Resource object represents an Amazon S3 bucket that your transferred data will be exported from or imported into. For export jobs, this object can have an optional KeyRange value. The length of the range is defined at job creation, and has either an inclusive BeginMarker , an inclusive EndMarker , or both. Ranges are UTF-8 binary sorted.
            BucketArn (string) --The Amazon Resource Name (ARN) of an Amazon S3 bucket.
            KeyRange (dict) --For export jobs, you can provide an optional KeyRange within a specific Amazon S3 bucket. The length of the range is defined at job creation, and has either an inclusive BeginMarker , an inclusive EndMarker , or both. Ranges are UTF-8 binary sorted.
            BeginMarker (string) --The key that starts an optional key range for an export job. Ranges are inclusive and UTF-8 binary sorted.
            EndMarker (string) --The key that ends an optional key range for an export job. Ranges are inclusive and UTF-8 binary sorted.
            
            
            
    :type Resources: dict
    :param AddressId: The ID of the updated Address object.
    :type AddressId: string
    :param ShippingOption: The updated shipping option value of this job's ShippingDetails object.
    :type ShippingOption: string
    :param Description: The updated description of this job's JobMetadata object.
    :type Description: string
    :param SnowballCapacityPreference: The updated SnowballCapacityPreference of this job's JobMetadata object. Note that the 50 TB Snowballs are only available in the US regions.
    :type SnowballCapacityPreference: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_attachments_to_set(attachmentSetId=None, attachments=None):
    """
    :param attachmentSetId: The ID of the attachment set. If an attachmentSetId is not specified, a new attachment set is created, and the ID of the set is returned in the response. If an attachmentSetId is specified, the attachments are added to the specified set, if it exists.
    :type attachmentSetId: string
    :param attachments: [REQUIRED]
            One or more attachments to add to the set. The limit is 3 attachments per set, and the size limit is 5 MB per attachment.
            (dict) --An attachment to a case communication. The attachment consists of the file name and the content of the file.
            fileName (string) --The name of the attachment file.
            data (bytes) --The content of the attachment file.
            
            
    :type attachments: list
    """
    pass

def add_communication_to_case(caseId=None, communicationBody=None, ccEmailAddresses=None, attachmentSetId=None):
    """
    :param caseId: The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47
    :type caseId: string
    :param communicationBody: [REQUIRED]
            The body of an email communication to add to the support case.
            
    :type communicationBody: string
    :param ccEmailAddresses: The email addresses in the CC line of an email to be added to the support case.
            (string) --
            
    :type ccEmailAddresses: list
    :param attachmentSetId: The ID of a set of one or more attachments for the communication to add to the case. Create the set by calling AddAttachmentsToSet
    :type attachmentSetId: string
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_case(subject=None, serviceCode=None, severityCode=None, categoryCode=None, communicationBody=None, ccEmailAddresses=None, language=None, issueType=None, attachmentSetId=None):
    """
    :param subject: [REQUIRED]
            The title of the AWS Support case.
            
    :type subject: string
    :param serviceCode: The code for the AWS service returned by the call to DescribeServices .
    :type serviceCode: string
    :param severityCode: The code for the severity level returned by the call to DescribeSeverityLevels .
            Note
            The availability of severity levels depends on each customer's support subscription. In other words, your subscription may not necessarily require the urgent level of response time.
            
    :type severityCode: string
    :param categoryCode: The category of problem for the AWS Support case.
    :type categoryCode: string
    :param communicationBody: [REQUIRED]
            The communication body text when you create an AWS Support case by calling CreateCase .
            
    :type communicationBody: string
    :param ccEmailAddresses: A list of email addresses that AWS Support copies on case correspondence.
            (string) --
            
    :type ccEmailAddresses: list
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.
    :type language: string
    :param issueType: The type of issue for the case. You can specify either 'customer-service' or 'technical.' If you do not indicate a value, the default is 'technical.'
    :type issueType: string
    :param attachmentSetId: The ID of a set of one or more attachments for the case. Create the set by using AddAttachmentsToSet .
    :type attachmentSetId: string
    """
    pass

def describe_attachment(attachmentId=None):
    """
    :param attachmentId: [REQUIRED]
            The ID of the attachment to return. Attachment IDs are returned by the DescribeCommunications operation.
            Return typedict
            ReturnsResponse Syntax{
              'attachment': {
                'fileName': 'string',
                'data': b'bytes'
              }
            }
            Response Structure
            (dict) --The content and file name of the attachment returned by the DescribeAttachment operation.
            attachment (dict) --The attachment content and file name.
            fileName (string) --The name of the attachment file.
            data (bytes) --The content of the attachment file.
            
            
            
    :type attachmentId: string
    """
    pass

def describe_cases(caseIdList=None, displayId=None, afterTime=None, beforeTime=None, includeResolvedCases=None, nextToken=None, maxResults=None, language=None, includeCommunications=None):
    """
    :param caseIdList: A list of ID numbers of the support cases you want returned. The maximum number of cases is 100.
            (string) --
            
    :type caseIdList: list
    :param displayId: The ID displayed for a case in the AWS Support Center user interface.
    :type displayId: string
    :param afterTime: The start date for a filtered date search on support case communications. Case communications are available for 12 months after creation.
    :type afterTime: string
    :param beforeTime: The end date for a filtered date search on support case communications. Case communications are available for 12 months after creation.
    :type beforeTime: string
    :param includeResolvedCases: Specifies whether resolved support cases should be included in the DescribeCases results. The default is false .
    :type includeResolvedCases: boolean
    :param nextToken: A resumption point for pagination.
    :type nextToken: string
    :param maxResults: The maximum number of results to return before paginating.
    :type maxResults: integer
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.
    :type language: string
    :param includeCommunications: Specifies whether communications should be included in the DescribeCases results. The default is true .
    :type includeCommunications: boolean
    """
    pass

def describe_communications(caseId=None, beforeTime=None, afterTime=None, nextToken=None, maxResults=None):
    """
    :param caseId: [REQUIRED]
            The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47
            
    :type caseId: string
    :param beforeTime: The end date for a filtered date search on support case communications. Case communications are available for 12 months after creation.
    :type beforeTime: string
    :param afterTime: The start date for a filtered date search on support case communications. Case communications are available for 12 months after creation.
    :type afterTime: string
    :param nextToken: A resumption point for pagination.
    :type nextToken: string
    :param maxResults: The maximum number of results to return before paginating.
    :type maxResults: integer
    """
    pass

def describe_services(serviceCodeList=None, language=None):
    """
    :param serviceCodeList: A JSON-formatted list of service codes available for AWS services.
            (string) --
            
    :type serviceCodeList: list
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.
    :type language: string
    """
    pass

def describe_severity_levels(language=None):
    """
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.
            Return typedict
            ReturnsResponse Syntax{
              'severityLevels': [
                {
                  'code': 'string',
                  'name': 'string'
                },
              ]
            }
            Response Structure
            (dict) --The list of severity levels returned by the DescribeSeverityLevels operation.
            severityLevels (list) --The available severity levels for the support case. Available severity levels are defined by your service level agreement with AWS.
            (dict) --A code and name pair that represent a severity level that can be applied to a support case.
            code (string) --One of four values: 'low,' 'medium,' 'high,' and 'urgent'. These values correspond to response times returned to the caller in severityLevel.name .
            name (string) --The name of the severity level that corresponds to the severity level code.
            
            
            
    :type language: string
    """
    pass

def describe_trusted_advisor_check_refresh_statuses(checkIds=None):
    """
    :param checkIds: [REQUIRED]
            The IDs of the Trusted Advisor checks to get the status of. Note: Specifying the check ID of a check that is automatically refreshed causes an InvalidParameterValue error.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'statuses': [
                {
                  'checkId': 'string',
                  'status': 'string',
                  'millisUntilNextRefreshable': 123
                },
              ]
            }
            Response Structure
            (dict) --The statuses of the Trusted Advisor checks returned by the DescribeTrustedAdvisorCheckRefreshStatuses operation.
            statuses (list) --The refresh status of the specified Trusted Advisor checks.
            (dict) --The refresh status of a Trusted Advisor check.
            checkId (string) --The unique identifier for the Trusted Advisor check.
            status (string) --The status of the Trusted Advisor check for which a refresh has been requested: 'none', 'enqueued', 'processing', 'success', or 'abandoned'.
            millisUntilNextRefreshable (integer) --The amount of time, in milliseconds, until the Trusted Advisor check is eligible for refresh.
            
            
            
    :type checkIds: list
    """
    pass

def describe_trusted_advisor_check_result(checkId=None, language=None):
    """
    :param checkId: [REQUIRED]
            The unique identifier for the Trusted Advisor check.
            
    :type checkId: string
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.
    :type language: string
    """
    pass

def describe_trusted_advisor_check_summaries(checkIds=None):
    """
    :param checkIds: [REQUIRED]
            The IDs of the Trusted Advisor checks.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'summaries': [
                {
                  'checkId': 'string',
                  'timestamp': 'string',
                  'status': 'string',
                  'hasFlaggedResources': True|False,
                  'resourcesSummary': {
                    'resourcesProcessed': 123,
                    'resourcesFlagged': 123,
                    'resourcesIgnored': 123,
                    'resourcesSuppressed': 123
                  },
                  'categorySpecificSummary': {
                    'costOptimizing': {
                      'estimatedMonthlySavings': 123.0,
                      'estimatedPercentMonthlySavings': 123.0
                    }
                  }
                },
              ]
            }
            Response Structure
            (dict) --The summaries of the Trusted Advisor checks returned by the DescribeTrustedAdvisorCheckSummaries operation.
            summaries (list) --The summary information for the requested Trusted Advisor checks.
            (dict) --A summary of a Trusted Advisor check result, including the alert status, last refresh, and number of resources examined.
            checkId (string) --The unique identifier for the Trusted Advisor check.
            timestamp (string) --The time of the last refresh of the check.
            status (string) --The alert status of the check: 'ok' (green), 'warning' (yellow), 'error' (red), or 'not_available'.
            hasFlaggedResources (boolean) --Specifies whether the Trusted Advisor check has flagged resources.
            resourcesSummary (dict) --Details about AWS resources that were analyzed in a call to Trusted Advisor DescribeTrustedAdvisorCheckSummaries .
            resourcesProcessed (integer) --The number of AWS resources that were analyzed by the Trusted Advisor check.
            resourcesFlagged (integer) --The number of AWS resources that were flagged (listed) by the Trusted Advisor check.
            resourcesIgnored (integer) --The number of AWS resources ignored by Trusted Advisor because information was unavailable.
            resourcesSuppressed (integer) --The number of AWS resources ignored by Trusted Advisor because they were marked as suppressed by the user.
            categorySpecificSummary (dict) --Summary information that relates to the category of the check. Cost Optimizing is the only category that is currently supported.
            costOptimizing (dict) --The summary information about cost savings for a Trusted Advisor check that is in the Cost Optimizing category.
            estimatedMonthlySavings (float) --The estimated monthly savings that might be realized if the recommended actions are taken.
            estimatedPercentMonthlySavings (float) --The estimated percentage of savings that might be realized if the recommended actions are taken.
            
            
            
            
    :type checkIds: list
    """
    pass

def describe_trusted_advisor_checks(language=None):
    """
    :param language: [REQUIRED]
            The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.
            Return typedict
            ReturnsResponse Syntax{
              'checks': [
                {
                  'id': 'string',
                  'name': 'string',
                  'description': 'string',
                  'category': 'string',
                  'metadata': [
                    'string',
                  ]
                },
              ]
            }
            Response Structure
            (dict) --Information about the Trusted Advisor checks returned by the DescribeTrustedAdvisorChecks operation.
            checks (list) --Information about all available Trusted Advisor checks.
            (dict) --The description and metadata for a Trusted Advisor check.
            id (string) --The unique identifier for the Trusted Advisor check.
            name (string) --The display name for the Trusted Advisor check.
            description (string) --The description of the Trusted Advisor check, which includes the alert criteria and recommended actions (contains HTML markup).
            category (string) --The category of the Trusted Advisor check.
            metadata (list) --The column headings for the data returned by the Trusted Advisor check. The order of the headings corresponds to the order of the data in the Metadata element of the TrustedAdvisorResourceDetail for the check. Metadata contains all the data that is shown in the Excel download, even in those cases where the UI shows just summary data.
            (string) --
            
            
            
    :type language: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def refresh_trusted_advisor_check(checkId=None):
    """
    :param checkId: [REQUIRED]
            The unique identifier for the Trusted Advisor check to refresh. Note: Specifying the check ID of a check that is automatically refreshed causes an InvalidParameterValue error.
            Return typedict
            ReturnsResponse Syntax{
              'status': {
                'checkId': 'string',
                'status': 'string',
                'millisUntilNextRefreshable': 123
              }
            }
            Response Structure
            (dict) --The current refresh status of a Trusted Advisor check.
            status (dict) --The current refresh status for a check, including the amount of time until the check is eligible for refresh.
            checkId (string) --The unique identifier for the Trusted Advisor check.
            status (string) --The status of the Trusted Advisor check for which a refresh has been requested: 'none', 'enqueued', 'processing', 'success', or 'abandoned'.
            millisUntilNextRefreshable (integer) --The amount of time, in milliseconds, until the Trusted Advisor check is eligible for refresh.
            
            
            
    :type checkId: string
    """
    pass

def resolve_case(caseId=None):
    """
    :param caseId: The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47
            Return typedict
            ReturnsResponse Syntax{
              'initialCaseStatus': 'string',
              'finalCaseStatus': 'string'
            }
            Response Structure
            (dict) --The status of the case returned by the ResolveCase operation.
            initialCaseStatus (string) --The status of the case when the ResolveCase request was sent.
            finalCaseStatus (string) --The status of the case after the ResolveCase request was processed.
            
            
    :type caseId: string
    """
    pass

